@@ -105,6 +105,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -220,6 +221,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
@@ -385,4 +387,4 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
-RegionName = Literal["us-east-1"]
+RegionName = Literal["eu-central-1", "us-east-1"]
